@@ -362,9 +362,6 @@ sub _symmetric_difference ($$) {
 
     $symmetric_difference->invert( $that->elements );
 
-    $symmetric_difference = $this
-	if $symmetric_difference->size == $this->size;
-
     return $symmetric_difference;
 }
 
@@ -452,12 +449,16 @@ sub is_null {
     return $self->size == 0;
 }
 
+*is_empty = \&is_null;
+
 sub null {
     my $self = shift;
 
     return $self->universe->null;
 }
 
+*empty = \&null;
+
 sub _compare {
     my $a = shift;
     my $b = shift;
